@@ -35,17 +35,23 @@
 #' `%i%` <- function(X, B) sapply(1:dim(X)[3], function(i) sum(X[,,i]*B))
 #'
 #' # Simulation data
-#' n <- 1000 # number of observations
+#' n <- 500 # number of observations
 #' n_P <- 3; n_G <- 64 # dimension of 3-D tensor variables.
-#' n_d <- 1 # number of numerical variable, if n_d == 1,  numerical variable equals to intercept.
+#' n_d <- 2 # number of numerical variable, if n_d == 1,  numerical variable equals to intercept.
 #' beta_True <- rep(1, n_d)
 #' B_True <- c(1,1,1)%*%t(rnorm(n_G)) + c(0, .5, .5)%*%t(rnorm(n_G))
 #' B_True <- B_True / 10
 #' W <- matrix(rnorm(n*n_d), n, n_d); W[,1] <- 1
+#' W_named <- W 
+#' colnames(W_named) <- paste0("w", 1:ncol(W_named))
 #' X <- array(rnorm(n*n_P*n_G), dim=c(n_P, n_G, n))
+#' X_named <- X
+#' dimnames(X_named) <- list(paste0("R", 1:nrow(X_named)),paste0("C", 1:ncol(X_named)))
 #' ## Regression
-#' y_R<- as.vector(W%*%beta_True + X%i%B_True + rnorm(n))
+#' y_R <- as.vector(W%*%beta_True + X%i%B_True + rnorm(n))
 #' DATA_R <- list(y = y_R, X = X, W = W)
+#' y_R_named <- as.vector(W_named%*%beta_True + X_named%i%B_True + rnorm(n))
+#' DATA_R_named <- list(y = y_R_named, X = X_named, W = W_named)
 #' ## Binomial
 #' p_B <- exp(W%*%beta_True + X%i%B_True); p_B <- p_B/(1+p_B)
 #' y_B <- rbinom(n, 1, p_B)
@@ -58,24 +64,28 @@
 #'
 #' # Execution
 #' ## Regression
-#' result_R <- TRtest.omics(y = DATA_R$y, X = DATA_R$X, W=NULL, n_R = 1, family = "gaussian",
+#' result_R <- TRtest(y = DATA_R$y, X = DATA_R$X, W=NULL, n_R = 1, family = "gaussian",
 #' opt = 1, max_ite = 100, tol = 10^(-7) )
 #' summary(result_R)
 #' head(predict(result_R, DATA_R$X))
+#' 
+#' ## Regression with specified names
+#' result_R_named <- TRtest(y = DATA_R_named$y, X = DATA_R_named$X, W=DATA_R_named$W,
+#' n_R = 1, family = "gaussian", opt = 1, max_ite = 100, tol = 10^(-7) )
+#' summary(result_R_named)
 #'
 #' ## Binomial
-#' result_B <- TRtest.omics(y = DATA_B$y, X = DATA_B$X, W=NULL, n_R = 1, family = "binomial",
+#' result_B <- TRtest(y = DATA_B$y, X = DATA_B$X, W=NULL, n_R = 1, family = "binomial",
 #' opt = 1, max_ite = 100, tol = 10^(-7) )
 #' summary(result_B)
 #' head(predict(result_B, DATA_B$X))
 #'
 #' ## Poisson
-#' result_P <- TRtest.omics(y = DATA_P$y, X = DATA_P$X, W=NULL, n_R = 1, family = "poisson",
+#' result_P <- TRtest(y = DATA_P$y, X = DATA_P$X, W=NULL, n_R = 1, family = "poisson",
 #' opt = 1, max_ite = 100, tol = 10^(-7) )
 #' summary(result_P)
 #' head(predict(result_P, DATA_P$X))
 #'
-#'
 #' @author Mark Chen
 #'
 #' @export
@@ -94,9 +104,20 @@ summary.tsglm <- function(object, ...){
     if( b == 1){
       names1 <- "(Intercept)"
     }else{
-      names1 <- c("(Intercept)", paste0("X", 1:(b-1)))
+      b_names <- rownames(object$b_EST)
+      if(is.null(b_names)){
+        names1 <- c("(Intercept)", paste0("X", 1:(b-1)))
+      }else{
+        names1 <- b_names
+      }
+    }
+    B_names <- dimnames(object$B_EST)
+    if(is.null(B_names)){
+      names2 <- paste0("X", 1:p, ".", rep(1:g, each = p))
+    }else{
+      names2 <- paste0(B_names[[1]], ':', rep(B_names[[2]],
+                                              each = length(B_names[[1]])))
     }
-    names2 <- paste0("X", 1:p, ".", rep(1:g, each = p))
     names <- c(names1, names2)
     mystarformat <- function(x) symnum(x, corr = FALSE, na = FALSE,
                                        cutpoints = c(0, 0.01, 0.05, 0.1, 1),
@@ -127,9 +148,20 @@ summary.tsglm <- function(object, ...){
     if( b == 1){
       names1 <- "(Intercept)"
     }else{
-      names1 <- c("(Intercept)", paste0("X", 1:(b-1)))
+      b_names <- rownames(object$b_EST)
+      if(is.null(b_names)){
+        names1 <- c("(Intercept)", paste0("X", 1:(b-1)))
+      }else{
+        names1 <- b_names
+      }
+    }
+    B_names <- dimnames(object$B_EST)
+    if(is.null(B_names)){
+      names2 <- paste0("X", 1:p, ".", rep(1:g, each = p))
+    }else{
+      names2 <- paste0(B_names[[1]], ':', rep(B_names[[2]],
+                                              each = length(B_names[[1]])))
     }
-    names2 <- paste0("X", 1:p, ".", rep(1:g, each = p))
     names <- c(names1, names2)
     mystarformat <- function(x) symnum(x, corr = FALSE, na = FALSE,
                                        cutpoints = c(0, 0.01, 0.05, 0.1, 1),
